HtmlExporter class

Centerpiece interactive HTML visualizer exporter.

Constructors

HtmlExporter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

export({required ScanResult result, required List<Cycle> cycles, String scope = 'cycles', bool offline = false}) String
Generates the single self-contained interactive HTML document.