ScanResult class

Holds the output of scanning a project repository.

Constructors

ScanResult({required String packageName, required Map<String, FileNode> files, required List<GraphEdge> edges, int workspacePackageCount = 1})
const

Properties

edges List<GraphEdge>
Directed edges between files in the project.
final
files Map<String, FileNode>
Map of scanned files by relative path (e.g., lib/auth.dart or packages/auth/lib/auth.dart).
final
hashCode int
The hash code for this object.
no setterinherited
isWorkspace bool
Whether this scan result represents a workspace/monorepo scan.
no setter
nodePaths List<String>
Returns unique relative paths of all scanned files.
no setter
packageName String
Name of the scanned package (from pubspec.yaml).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
workspacePackageCount int
Number of member packages discovered if scanning in workspace/monorepo mode.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited