DependencyGraph class
Represents the dependency graph of a scanned Dart project.
Constructors
- DependencyGraph.fromScanResult(ScanResult result)
-
Factory constructor to construct a graph from a ScanResult.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
incomingEdges
→ Map<
String, Set< String> > -
Map from file path to set of file paths that import/export it (incoming edges).
final
-
outgoingEdges
→ Map<
String, Set< String> > -
Map from file path to set of file paths it imports/exports (outgoing edges).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scanResult → ScanResult
-
The underlying scan result metadata.
final
Methods
-
findCircularDependencies(
) → List< Cycle> - Finds all circular dependencies in the graph.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited